@@ -30,6 +30,8 @@ import jsii
 import publication
 import typing_extensions
 
+from typeguard import check_type
+
 from ._jsii import *
 
 import aws_cdk.aws_s3
@@ -48,8 +50,8 @@ class BucketReplication(
         *,
         destination_bucket: aws_cdk.aws_s3.IBucket,
         source_bucket: aws_cdk.aws_s3.IBucket,
-        replication_destination_properties: typing.Optional["ReplicationDestinationPropertyNoBucket"] = None,
-        replication_rule_properties: typing.Optional["ReplicationRulePropertyNoDestination"] = None,
+        replication_destination_properties: typing.Optional[typing.Union["ReplicationDestinationPropertyNoBucket", typing.Dict[str, typing.Any]]] = None,
+        replication_rule_properties: typing.Optional[typing.Union["ReplicationRulePropertyNoDestination", typing.Dict[str, typing.Any]]] = None,
     ) -> None:
         '''
         :param scope: -
@@ -59,6 +61,20 @@ class BucketReplication(
         :param replication_destination_properties: 
         :param replication_rule_properties: 
         '''
+        if __debug__:
+            def stub(
+                scope: aws_cdk.core.Construct,
+                id: builtins.str,
+                *,
+                destination_bucket: aws_cdk.aws_s3.IBucket,
+                source_bucket: aws_cdk.aws_s3.IBucket,
+                replication_destination_properties: typing.Optional[typing.Union["ReplicationDestinationPropertyNoBucket", typing.Dict[str, typing.Any]]] = None,
+                replication_rule_properties: typing.Optional[typing.Union["ReplicationRulePropertyNoDestination", typing.Dict[str, typing.Any]]] = None,
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
+            check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
+            check_type(argname="argument id", value=id, expected_type=type_hints["id"])
         props = BucketReplicationProps(
             destination_bucket=destination_bucket,
             source_bucket=source_bucket,
@@ -85,8 +101,8 @@ class BucketReplicationProps:
         *,
         destination_bucket: aws_cdk.aws_s3.IBucket,
         source_bucket: aws_cdk.aws_s3.IBucket,
-        replication_destination_properties: typing.Optional["ReplicationDestinationPropertyNoBucket"] = None,
-        replication_rule_properties: typing.Optional["ReplicationRulePropertyNoDestination"] = None,
+        replication_destination_properties: typing.Optional[typing.Union["ReplicationDestinationPropertyNoBucket", typing.Dict[str, typing.Any]]] = None,
+        replication_rule_properties: typing.Optional[typing.Union["ReplicationRulePropertyNoDestination", typing.Dict[str, typing.Any]]] = None,
     ) -> None:
         '''
         :param destination_bucket: 
@@ -98,6 +114,20 @@ class BucketReplicationProps:
             replication_destination_properties = ReplicationDestinationPropertyNoBucket(**replication_destination_properties)
         if isinstance(replication_rule_properties, dict):
             replication_rule_properties = ReplicationRulePropertyNoDestination(**replication_rule_properties)
+        if __debug__:
+            def stub(
+                *,
+                destination_bucket: aws_cdk.aws_s3.IBucket,
+                source_bucket: aws_cdk.aws_s3.IBucket,
+                replication_destination_properties: typing.Optional[typing.Union["ReplicationDestinationPropertyNoBucket", typing.Dict[str, typing.Any]]] = None,
+                replication_rule_properties: typing.Optional[typing.Union["ReplicationRulePropertyNoDestination", typing.Dict[str, typing.Any]]] = None,
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
+            check_type(argname="argument destination_bucket", value=destination_bucket, expected_type=type_hints["destination_bucket"])
+            check_type(argname="argument source_bucket", value=source_bucket, expected_type=type_hints["source_bucket"])
+            check_type(argname="argument replication_destination_properties", value=replication_destination_properties, expected_type=type_hints["replication_destination_properties"])
+            check_type(argname="argument replication_rule_properties", value=replication_rule_properties, expected_type=type_hints["replication_rule_properties"])
         self._values: typing.Dict[str, typing.Any] = {
             "destination_bucket": destination_bucket,
             "source_bucket": source_bucket,
@@ -161,11 +191,11 @@ class ReplicationDestinationPropertyNoBucket:
     def __init__(
         self,
         *,
-        access_control_translation: typing.Optional[typing.Union[aws_cdk.core.IResolvable, aws_cdk.aws_s3.CfnBucket.AccessControlTranslationProperty]] = None,
+        access_control_translation: typing.Optional[typing.Union[aws_cdk.core.IResolvable, typing.Union[aws_cdk.aws_s3.CfnBucket.AccessControlTranslationProperty, typing.Dict[str, typing.Any]]]] = None,
         account: typing.Optional[builtins.str] = None,
-        encryption_configuration: typing.Optional[typing.Union[aws_cdk.core.IResolvable, aws_cdk.aws_s3.CfnBucket.EncryptionConfigurationProperty]] = None,
-        metrics: typing.Optional[typing.Union[aws_cdk.core.IResolvable, aws_cdk.aws_s3.CfnBucket.MetricsProperty]] = None,
-        replication_time: typing.Optional[typing.Union[aws_cdk.core.IResolvable, aws_cdk.aws_s3.CfnBucket.ReplicationTimeProperty]] = None,
+        encryption_configuration: typing.Optional[typing.Union[aws_cdk.core.IResolvable, typing.Union[aws_cdk.aws_s3.CfnBucket.EncryptionConfigurationProperty, typing.Dict[str, typing.Any]]]] = None,
+        metrics: typing.Optional[typing.Union[aws_cdk.core.IResolvable, typing.Union[aws_cdk.aws_s3.CfnBucket.MetricsProperty, typing.Dict[str, typing.Any]]]] = None,
+        replication_time: typing.Optional[typing.Union[aws_cdk.core.IResolvable, typing.Union[aws_cdk.aws_s3.CfnBucket.ReplicationTimeProperty, typing.Dict[str, typing.Any]]]] = None,
         storage_class: typing.Optional["ReplicationDestinationStorageClass"] = None,
     ) -> None:
         '''
@@ -176,6 +206,24 @@ class ReplicationDestinationPropertyNoBucket:
         :param replication_time: 
         :param storage_class: 
         '''
+        if __debug__:
+            def stub(
+                *,
+                access_control_translation: typing.Optional[typing.Union[aws_cdk.core.IResolvable, typing.Union[aws_cdk.aws_s3.CfnBucket.AccessControlTranslationProperty, typing.Dict[str, typing.Any]]]] = None,
+                account: typing.Optional[builtins.str] = None,
+                encryption_configuration: typing.Optional[typing.Union[aws_cdk.core.IResolvable, typing.Union[aws_cdk.aws_s3.CfnBucket.EncryptionConfigurationProperty, typing.Dict[str, typing.Any]]]] = None,
+                metrics: typing.Optional[typing.Union[aws_cdk.core.IResolvable, typing.Union[aws_cdk.aws_s3.CfnBucket.MetricsProperty, typing.Dict[str, typing.Any]]]] = None,
+                replication_time: typing.Optional[typing.Union[aws_cdk.core.IResolvable, typing.Union[aws_cdk.aws_s3.CfnBucket.ReplicationTimeProperty, typing.Dict[str, typing.Any]]]] = None,
+                storage_class: typing.Optional["ReplicationDestinationStorageClass"] = None,
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
+            check_type(argname="argument access_control_translation", value=access_control_translation, expected_type=type_hints["access_control_translation"])
+            check_type(argname="argument account", value=account, expected_type=type_hints["account"])
+            check_type(argname="argument encryption_configuration", value=encryption_configuration, expected_type=type_hints["encryption_configuration"])
+            check_type(argname="argument metrics", value=metrics, expected_type=type_hints["metrics"])
+            check_type(argname="argument replication_time", value=replication_time, expected_type=type_hints["replication_time"])
+            check_type(argname="argument storage_class", value=storage_class, expected_type=type_hints["storage_class"])
         self._values: typing.Dict[str, typing.Any] = {}
         if access_control_translation is not None:
             self._values["access_control_translation"] = access_control_translation
@@ -269,12 +317,12 @@ class ReplicationRulePropertyNoDestination:
     def __init__(
         self,
         *,
-        delete_marker_replication: typing.Optional[typing.Union[aws_cdk.core.IResolvable, aws_cdk.aws_s3.CfnBucket.DeleteMarkerReplicationProperty]] = None,
-        filter: typing.Optional[typing.Union[aws_cdk.core.IResolvable, aws_cdk.aws_s3.CfnBucket.ReplicationRuleFilterProperty]] = None,
+        delete_marker_replication: typing.Optional[typing.Union[aws_cdk.core.IResolvable, typing.Union[aws_cdk.aws_s3.CfnBucket.DeleteMarkerReplicationProperty, typing.Dict[str, typing.Any]]]] = None,
+        filter: typing.Optional[typing.Union[aws_cdk.core.IResolvable, typing.Union[aws_cdk.aws_s3.CfnBucket.ReplicationRuleFilterProperty, typing.Dict[str, typing.Any]]]] = None,
         id: typing.Optional[builtins.str] = None,
         prefix: typing.Optional[builtins.str] = None,
         priority: typing.Optional[jsii.Number] = None,
-        source_selection_criteria: typing.Optional[typing.Union[aws_cdk.core.IResolvable, aws_cdk.aws_s3.CfnBucket.SourceSelectionCriteriaProperty]] = None,
+        source_selection_criteria: typing.Optional[typing.Union[aws_cdk.core.IResolvable, typing.Union[aws_cdk.aws_s3.CfnBucket.SourceSelectionCriteriaProperty, typing.Dict[str, typing.Any]]]] = None,
         status: typing.Optional["ReplicationRuleStatus"] = None,
     ) -> None:
         '''
@@ -286,6 +334,26 @@ class ReplicationRulePropertyNoDestination:
         :param source_selection_criteria: 
         :param status: 
         '''
+        if __debug__:
+            def stub(
+                *,
+                delete_marker_replication: typing.Optional[typing.Union[aws_cdk.core.IResolvable, typing.Union[aws_cdk.aws_s3.CfnBucket.DeleteMarkerReplicationProperty, typing.Dict[str, typing.Any]]]] = None,
+                filter: typing.Optional[typing.Union[aws_cdk.core.IResolvable, typing.Union[aws_cdk.aws_s3.CfnBucket.ReplicationRuleFilterProperty, typing.Dict[str, typing.Any]]]] = None,
+                id: typing.Optional[builtins.str] = None,
+                prefix: typing.Optional[builtins.str] = None,
+                priority: typing.Optional[jsii.Number] = None,
+                source_selection_criteria: typing.Optional[typing.Union[aws_cdk.core.IResolvable, typing.Union[aws_cdk.aws_s3.CfnBucket.SourceSelectionCriteriaProperty, typing.Dict[str, typing.Any]]]] = None,
+                status: typing.Optional["ReplicationRuleStatus"] = None,
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
+            check_type(argname="argument delete_marker_replication", value=delete_marker_replication, expected_type=type_hints["delete_marker_replication"])
+            check_type(argname="argument filter", value=filter, expected_type=type_hints["filter"])
+            check_type(argname="argument id", value=id, expected_type=type_hints["id"])
+            check_type(argname="argument prefix", value=prefix, expected_type=type_hints["prefix"])
+            check_type(argname="argument priority", value=priority, expected_type=type_hints["priority"])
+            check_type(argname="argument source_selection_criteria", value=source_selection_criteria, expected_type=type_hints["source_selection_criteria"])
+            check_type(argname="argument status", value=status, expected_type=type_hints["status"])
         self._values: typing.Dict[str, typing.Any] = {}
         if delete_marker_replication is not None:
             self._values["delete_marker_replication"] = delete_marker_replication
